pub struct RedeemReserveCollateral {
pub owner: Pubkey,
pub lending_market: Pubkey,
pub reserve: Pubkey,
pub lending_market_authority: Pubkey,
pub reserve_collateral_mint: Pubkey,
pub reserve_liquidity_supply: Pubkey,
pub user_source_collateral: Pubkey,
pub user_destination_liquidity: Pubkey,
pub token_program: Pubkey,
}Expand description
Generated client accounts for RedeemReserveCollateral.
Fields
owner: Pubkeylending_market: Pubkeyreserve: Pubkeyreserve_collateral_mint: Pubkeyreserve_liquidity_supply: Pubkeyuser_source_collateral: Pubkeyuser_destination_liquidity: Pubkeytoken_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for RedeemReserveCollateralwhere
Pubkey: BorshSerialize,
impl BorshSerialize for RedeemReserveCollateralwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for RedeemReserveCollateral
impl ToAccountMetas for RedeemReserveCollateral
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for RedeemReserveCollateral
impl RefUnwindSafe for RedeemReserveCollateral
impl Send for RedeemReserveCollateral
impl Sync for RedeemReserveCollateral
impl Unpin for RedeemReserveCollateral
impl UnwindSafe for RedeemReserveCollateral