pub struct InitLendingMarket {
pub _quote_currency: [u8; 32],
}Expand description
Instruction.
Fields
_quote_currency: [u8; 32]Trait Implementations
Sourceimpl BorshDeserialize for InitLendingMarket
impl BorshDeserialize for InitLendingMarket
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for InitLendingMarket
impl BorshSerialize for InitLendingMarket
Sourceimpl Discriminator for InitLendingMarket
impl Discriminator for InitLendingMarket
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for InitLendingMarket
impl InstructionData for InitLendingMarket