pub struct WithdrawObligationCollateral<'info> {
pub owner: Signer<'info>,
pub obligation: AccountInfo<'info>,
pub lending_market: AccountInfo<'info>,
pub lending_market_authority: AccountInfo<'info>,
pub withdraw_reserve: AccountInfo<'info>,
pub reserve_source_collateral: AccountInfo<'info>,
pub user_destination_collateral: AccountInfo<'info>,
pub token_program: AccountInfo<'info>,
pub instruction_sysvar_account: AccountInfo<'info>,
}Fields
owner: Signer<'info>obligation: AccountInfo<'info>lending_market: AccountInfo<'info>withdraw_reserve: AccountInfo<'info>reserve_source_collateral: AccountInfo<'info>user_destination_collateral: AccountInfo<'info>token_program: AccountInfo<'info>instruction_sysvar_account: AccountInfo<'info>Trait Implementations
Sourceimpl<'info> Accounts<'info, WithdrawObligationCollateralBumps> for WithdrawObligationCollateral<'info>where
'info: 'info,
impl<'info> Accounts<'info, WithdrawObligationCollateralBumps> for WithdrawObligationCollateral<'info>where
'info: 'info,
Sourcefn try_accounts(
__program_id: &Pubkey,
__accounts: &mut &'info [AccountInfo<'info>],
__ix_data: &[u8],
__bumps: &mut WithdrawObligationCollateralBumps,
__reallocs: &mut BTreeSet<Pubkey>,
) -> Result<Self>
fn try_accounts( __program_id: &Pubkey, __accounts: &mut &'info [AccountInfo<'info>], __ix_data: &[u8], __bumps: &mut WithdrawObligationCollateralBumps, __reallocs: &mut BTreeSet<Pubkey>, ) -> Result<Self>
Returns the validated accounts struct. What constitutes “valid” is
program dependent. However, users of these types should never have to
worry about account substitution attacks. For example, if a program
expects a
Mint account from the SPL token program in a particular
field, then it should be impossible for this method to return Ok if
any other account type is given–from the SPL token program or elsewhere. Read moreSourceimpl<'info> AccountsExit<'info> for WithdrawObligationCollateral<'info>where
'info: 'info,
impl<'info> AccountsExit<'info> for WithdrawObligationCollateral<'info>where
'info: 'info,
Sourceimpl<'info> Bumps for WithdrawObligationCollateral<'info>where
'info: 'info,
impl<'info> Bumps for WithdrawObligationCollateral<'info>where
'info: 'info,
Sourcetype Bumps = WithdrawObligationCollateralBumps
type Bumps = WithdrawObligationCollateralBumps
Struct to hold account bump seeds.
Sourceimpl<'info> ToAccountInfos<'info> for WithdrawObligationCollateral<'info>where
'info: 'info,
impl<'info> ToAccountInfos<'info> for WithdrawObligationCollateral<'info>where
'info: 'info,
fn to_account_infos(&self) -> Vec<AccountInfo<'info>>
Sourceimpl<'info> ToAccountMetas for WithdrawObligationCollateral<'info>
impl<'info> ToAccountMetas for WithdrawObligationCollateral<'info>
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl<'info> Freeze for WithdrawObligationCollateral<'info>
impl<'info> !RefUnwindSafe for WithdrawObligationCollateral<'info>
impl<'info> !Send for WithdrawObligationCollateral<'info>
impl<'info> !Sync for WithdrawObligationCollateral<'info>
impl<'info> Unpin for WithdrawObligationCollateral<'info>
impl<'info> !UnwindSafe for WithdrawObligationCollateral<'info>