pub struct Obligation {Show 18 fields
pub tag: u64,
pub last_update: LastUpdate,
pub lending_market: Pubkey,
pub owner: Pubkey,
pub deposits: [ObligationCollateral; 8],
pub lowest_reserve_deposit_ltv: u64,
pub deposited_value_sf: u128,
pub borrows: [ObligationLiquidity; 5],
pub borrow_factor_adjusted_debt_value_sf: u128,
pub borrowed_assets_market_value_sf: u128,
pub allowed_borrow_value_sf: u128,
pub unhealthy_borrow_value_sf: u128,
pub deposits_asset_tiers: [u8; 8],
pub borrows_asset_tiers: [u8; 5],
pub elevation_group: u8,
pub reserved: [u8; 2],
pub referrer: Pubkey,
pub padding3: [u64; 128],
}Expand description
Account: Obligation
Fields
tag: u64last_update: LastUpdatelending_market: Pubkeyowner: Pubkeydeposits: [ObligationCollateral; 8]lowest_reserve_deposit_ltv: u64deposited_value_sf: u128borrows: [ObligationLiquidity; 5]borrow_factor_adjusted_debt_value_sf: u128borrowed_assets_market_value_sf: u128allowed_borrow_value_sf: u128unhealthy_borrow_value_sf: u128deposits_asset_tiers: [u8; 8]borrows_asset_tiers: [u8; 5]elevation_group: u8reserved: [u8; 2]referrer: Pubkeypadding3: [u64; 128]Trait Implementations
Sourceimpl AccountDeserialize for Obligation
impl AccountDeserialize for Obligation
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for Obligation
impl AccountSerialize for Obligation
Sourceimpl BorshDeserialize for Obligationwhere
u64: BorshDeserialize,
LastUpdate: BorshDeserialize,
Pubkey: BorshDeserialize,
[ObligationCollateral; 8]: BorshDeserialize,
u128: BorshDeserialize,
[ObligationLiquidity; 5]: BorshDeserialize,
[u8; 8]: BorshDeserialize,
[u8; 5]: BorshDeserialize,
u8: BorshDeserialize,
[u8; 2]: BorshDeserialize,
[u64; 128]: BorshDeserialize,
impl BorshDeserialize for Obligationwhere
u64: BorshDeserialize,
LastUpdate: BorshDeserialize,
Pubkey: BorshDeserialize,
[ObligationCollateral; 8]: BorshDeserialize,
u128: BorshDeserialize,
[ObligationLiquidity; 5]: BorshDeserialize,
[u8; 8]: BorshDeserialize,
[u8; 5]: BorshDeserialize,
u8: BorshDeserialize,
[u8; 2]: BorshDeserialize,
[u64; 128]: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Obligationwhere
u64: BorshSerialize,
LastUpdate: BorshSerialize,
Pubkey: BorshSerialize,
[ObligationCollateral; 8]: BorshSerialize,
u128: BorshSerialize,
[ObligationLiquidity; 5]: BorshSerialize,
[u8; 8]: BorshSerialize,
[u8; 5]: BorshSerialize,
u8: BorshSerialize,
[u8; 2]: BorshSerialize,
[u64; 128]: BorshSerialize,
impl BorshSerialize for Obligationwhere
u64: BorshSerialize,
LastUpdate: BorshSerialize,
Pubkey: BorshSerialize,
[ObligationCollateral; 8]: BorshSerialize,
u128: BorshSerialize,
[ObligationLiquidity; 5]: BorshSerialize,
[u8; 8]: BorshSerialize,
[u8; 5]: BorshSerialize,
u8: BorshSerialize,
[u8; 2]: BorshSerialize,
[u64; 128]: BorshSerialize,
Sourceimpl Clone for Obligation
impl Clone for Obligation
Sourcefn clone(&self) -> Obligation
fn clone(&self) -> Obligation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Discriminator for Obligation
impl Discriminator for Obligation
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
impl Copy for Obligation