pub struct ScopeConfiguration {
pub price_feed: Pubkey,
pub price_chain: [u16; 4],
pub twap_chain: [u16; 4],
}Fields
price_feed: Pubkeyprice_chain: [u16; 4]twap_chain: [u16; 4]Trait Implementations
Sourceimpl BorshDeserialize for ScopeConfiguration
impl BorshDeserialize for ScopeConfiguration
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ScopeConfiguration
impl BorshSerialize for ScopeConfiguration
Sourceimpl Clone for ScopeConfiguration
impl Clone for ScopeConfiguration
Sourcefn clone(&self) -> ScopeConfiguration
fn clone(&self) -> ScopeConfiguration
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScopeConfiguration
impl Debug for ScopeConfiguration
Sourceimpl Default for ScopeConfiguration
impl Default for ScopeConfiguration
Sourcefn default() -> ScopeConfiguration
fn default() -> ScopeConfiguration
Returns the “default value” for a type. Read more
impl Copy for ScopeConfiguration